!-------------------------------------------------------------------------------

!                      Code_Saturne version 3.3.2
!                      --------------------------
! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2014 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.

!-------------------------------------------------------------------------------

!===============================================================================
! Purpose:
! -------

!> \file cs_user_extra_operations.f90
!>
!> \brief This function is called at the end of each time step, and has a very
!>  general purpose
!>  (i.e. anything that does not have another dedicated user subroutine)
!>
!-------------------------------------------------------------------------------

!-------------------------------------------------------------------------------
! Arguments
!______________________________________________________________________________.
!  mode           name          role                                           !
!______________________________________________________________________________!
!> \param[in]     nvar          total number of variables
!> \param[in]     nscal         total number of scalars
!> \param[in]     dt            time step (per cell)
!_______________________________________________________________________________

subroutine cs_f_user_extra_operations &
 ( nvar   , nscal  ,                                              &
   dt     )

!===============================================================================

!===============================================================================
! Module files
!===============================================================================

use paramx
use dimens, only: ndimfb
use pointe
use numvar
use optcal
use cstphy
use cstnum
use entsor
use lagpar
use lagran
use lagdim
use parall
use period
use ppppar
use ppthch
use ppincl
use mesh
use field
use field_operator
use turbomachinery

!===============================================================================

implicit none

! Arguments

integer          nvar   , nscal

double precision dt(ncelet)

! Local variables

double precision usp1, usp2, usp3

integer npt, usp4

!===============================================================================

!===============================================================================
! Initialization
!===============================================================================

usp1=0.d0
usp2=0.d0
usp3=0.d0
usp4=0

!===============================================================================
! User operations
!===============================================================================

do npt=1,nbpart
    
    usp1=ettp(npt,jvp)
    !usp2=5*usp1
    usp2=81.d0
    ettp(npt,jvls(1))=usp2
    usp3=ettp(npt,jvls(1))
    usp4=jvls(1)
    
    !Show some text advertisement during execution
    !write(nfecra,90109) usp1, usp2, usp3, usp4
    !90109 format('Calculated values: usp1=',f10.3,'/ usp2=',f10.3,'/ usp3=',f10.3,'/ usp4=',i3)
    
    

enddo

!--------
! Formats
!--------

!----
! End
!----


return
end subroutine cs_f_user_extra_operations
